summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorSven Eden <yamakuzure@gmx.net>2017-01-19 13:04:18 +0100
committerSven Eden <yamakuzure@gmx.net>2017-03-14 10:23:02 +0100
commitb514d6c9dcc7c0d7353f975ecfb94f2197c73cf1 (patch)
tree6fbc248a58ba3d6062082137c876c6020807d230 /tools
parent167bf427227158dbcad675d951e67038f23a9486 (diff)
Fix man page building to be less systemd and more elogind.
Diffstat (limited to 'tools')
-rwxr-xr-xtools/make-directive-index.py101
-rwxr-xr-xtools/make-man-index.py22
2 files changed, 25 insertions, 98 deletions
diff --git a/tools/make-directive-index.py b/tools/make-directive-index.py
index 17b1325bb..183eca3bb 100755
--- a/tools/make-directive-index.py
+++ b/tools/make-directive-index.py
@@ -1,21 +1,21 @@
# -*- Mode: python; coding: utf-8; indent-tabs-mode: nil -*- */
#
# This file is part of systemd.
#
# Copyright 2012-2013 Zbigniew Jędrzejewski-Szmek
#
# systemd is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 2.1 of the License, or
# (at your option) any later version.
#
# systemd is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
-# along with systemd; If not, see <http://www.gnu.org/licenses/>.
+# along with elogind; If not, see <http://www.gnu.org/licenses/>.
import sys
import collections
@@ -24,11 +24,11 @@ from xml_helper import *
from copy import deepcopy
TEMPLATE = '''\
-<refentry id="systemd.directives" conditional="HAVE_PYTHON">
+<refentry id="elogind.directives" conditional="HAVE_PYTHON">
<refentryinfo>
- <title>systemd.directives</title>
- <productname>systemd</productname>
+ <title>elogind.directives</title>
+ <productname>elogind</productname>
<authorgroup>
<author>
@@ -41,70 +41,16 @@ TEMPLATE = '''\
</refentryinfo>
<refmeta>
- <refentrytitle>systemd.directives</refentrytitle>
+ <refentrytitle>elogind.directives</refentrytitle>
<manvolnum>7</manvolnum>
</refmeta>
<refnamediv>
- <refname>systemd.directives</refname>
+ <refname>elogind.directives</refname>
<refpurpose>Index of configuration directives</refpurpose>
</refnamediv>
<refsect1>
- <title>Unit directives</title>
-
- <para>Directives for configuring units, used in unit
- files.</para>
-
- <variablelist id='unit-directives' />
- </refsect1>
-
- <refsect1>
- <title>Options on the kernel command line</title>
-
- <para>Kernel boot options for configuring the behaviour of the
- systemd process.</para>
-
- <variablelist id='kernel-commandline-options' />
- </refsect1>
-
- <refsect1>
- <title>Environment variables</title>
-
- <para>Environment variables understood by the systemd
- manager and other programs.</para>
-
- <variablelist id='environment-variables' />
- </refsect1>
-
- <refsect1>
- <title>UDEV directives</title>
-
- <para>Directives for configuring systemd units through the
- udev database.</para>
-
- <variablelist id='udev-directives' />
- </refsect1>
-
- <refsect1>
- <title>Network directives</title>
-
- <para>Directives for configuring network links through the
- net-setup-link udev builtin and networks through
- systemd-networkd.</para>
-
- <variablelist id='network-directives' />
- </refsect1>
-
- <refsect1>
- <title>Journal fields</title>
-
- <para>Fields in the journal events with a well known meaning.</para>
-
- <variablelist id='journal-directives' />
- </refsect1>
-
- <refsect1>
<title>PAM configuration directives</title>
<para>Directives for configuring PAM behaviour.</para>
@@ -113,38 +59,19 @@ TEMPLATE = '''\
</refsect1>
<refsect1>
- <title><filename>/etc/crypttab</filename> and
- <filename>/etc/fstab</filename> options</title>
-
- <para>Options which influence mounted filesystems and
- encrypted volumes.</para>
-
- <variablelist id='fstab-options' />
- </refsect1>
-
- <refsect1>
- <title>System manager directives</title>
-
- <para>Directives for configuring the behaviour of the
- systemd process.</para>
-
- <variablelist id='systemd-directives' />
- </refsect1>
-
- <refsect1>
- <title>bootchart.conf directives</title>
+ <title>elogind manager directives</title>
<para>Directives for configuring the behaviour of the
- systemd-bootchart process.</para>
+ elogind process.</para>
- <variablelist id='bootchart-directives' />
+ <variablelist id='elogind-directives' />
</refsect1>
<refsect1>
<title>command line options</title>
<para>Command-line options accepted by programs in the
- systemd suite.</para>
+ elogind suite.</para>
<variablelist id='options' />
</refsect1>
@@ -152,7 +79,7 @@ TEMPLATE = '''\
<refsect1>
<title>Constants</title>
- <para>Various constant used and/or defined by systemd.</para>
+ <para>Various constant used and/or defined by elogind.</para>
<variablelist id='constants' />
</refsect1>
@@ -1,21 +1,21 @@
# -*- Mode: python; coding: utf-8; indent-tabs-mode: nil -*- */
#
-# This file is part of systemd.
+# This file is part of elogind.
#
# Copyright 2012-2013 Zbigniew Jędrzejewski-Szmek
@@ -1,21 +1,21 @@
# Copyright 2012-2013 Zbigniew Jędrzejewski-Szmek
#
-# systemd is free software; you can redistribute it and/or modify it
+# elogind is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 2.1 of the License, or
@@ -1,21 +1,21 @@
# (at your option) any later version.
#
-# systemd is distributed in the hope that it will be useful, but
+# elogind is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
diff --git a/tools/make-man-index.py b/tools/make-man-index.py
index 74a47b821..396188212 100755
--- a/tools/make-man-index.py
+++ b/tools/make-man-index.py
@@ -1,22 +1,22 @@
# -*- Mode: python; coding: utf-8; indent-tabs-mode: nil -*- */
#
# This file is part of systemd.
#
# Copyright 2012 Lennart Poettering
# Copyright 2013 Zbigniew Jędrzejewski-Szmek
#
# systemd is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 2.1 of the License, or
# (at your option) any later version.
#
# systemd is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
-# along with systemd; If not, see <http://www.gnu.org/licenses/>.
+# along with elogind; If not, see <http://www.gnu.org/licenses/>.
import collections
import sys
@@ -26,11 +26,11 @@ from xml_helper import *
MDASH = ' — ' if sys.version_info.major >= 3 else ' -- '
TEMPLATE = '''\
-<refentry id="systemd.index" conditional="HAVE_PYTHON">
+<refentry id="elogind.index" conditional="HAVE_PYTHON">
<refentryinfo>
- <title>systemd.index</title>
- <productname>systemd</productname>
+ <title>elogind.index</title>
+ <productname>elogind</productname>
<authorgroup>
<author>
@@ -43,13 +43,13 @@ TEMPLATE = '''\
</refentryinfo>
<refmeta>
- <refentrytitle>systemd.index</refentrytitle>
+ <refentrytitle>elogind.index</refentrytitle>
<manvolnum>7</manvolnum>
</refmeta>
<refnamediv>
- <refname>systemd.index</refname>
- <refpurpose>List all manpages from the systemd project</refpurpose>
+ <refname>elogind.index</refname>
+ <refpurpose>List all manpages from the elogind project</refpurpose>
</refnamediv>
</refentry>
'''
@@ -58,7 +58,7 @@ SUMMARY = '''\
<refsect1>
<title>See Also</title>
<para>
- <citerefentry><refentrytitle>systemd.directives</refentrytitle><manvolnum>7</manvolnum></citerefentry>
+ <citerefentry><refentrytitle>elogind.directives</refentrytitle><manvolnum>7</manvolnum></citerefentry>
</para>
<para id='counts' />
@@ -1,22 +1,22 @@
# -*- Mode: python; coding: utf-8; indent-tabs-mode: nil -*- */
#
-# This file is part of systemd.
+# This file is part of elogind.
#
# Copyright 2012 Lennart Poettering
@@ -1,22 +1,22 @@
# Copyright 2013 Zbigniew Jędrzejewski-Szmek
#
-# systemd is free software; you can redistribute it and/or modify it
+# elogind is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 2.1 of the License, or
@@ -1,22 +1,22 @@
# (at your option) any later version.
#
-# systemd is distributed in the hope that it will be useful, but
+# elogind is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU